@@ -30,17 +30,17 @@ extern "C" {
 #define MagickLibVersion  0x712
 #define MagickLibVersionText  "7.1.2"
 #define MagickLibVersionNumber  10,0,2
-#define MagickLibAddendum  "-1"
+#define MagickLibAddendum  "-2"
 #define MagickLibInterface  10
 #define MagickLibMinInterface  10
-#define MagickPlatform  "armv6"
+#define MagickPlatform  "aarch64"
 #define MagickppLibVersionText  "7.1.2"
 #define MagickppLibVersionNumber  5:0:0
-#define MagickppLibAddendum  "-1"
+#define MagickppLibAddendum  "-2"
 #define MagickppLibInterface  5
 #define MagickppLibMinInterface  5
-#define MagickGitRevision  "23308"
-#define MagickReleaseDate  "2025-08-12"
+#define MagickGitRevision  "23332"
+#define MagickReleaseDate  "2025-08-24"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
